pub fn clean_cache(
cache: &GlobalCache,
use_official_command: bool,
) -> Result<CleanResult>Expand description
Clean a cache using the official command if available, otherwise rm -rf
pub fn clean_cache(
cache: &GlobalCache,
use_official_command: bool,
) -> Result<CleanResult>Clean a cache using the official command if available, otherwise rm -rf