BinarySource

Enum BinarySource 

pub enum BinarySource {
Show 21 variants System, Homebrew, HomebrewCask, Cargo, Pip, Pipx, Uv, Npm, Pyenv, Rbenv, Rvm, Nvm, Fnm, Volta, Rustup, Sdkman, Gvm, Mise, Asdf, Manual, Unknown,
}
Binary source - where a binary was installed from

Variants



System

System binary (/usr/bin/, /bin/)



Homebrew

Homebrew (Apple Silicon: /opt/homebrew/, Intel: /usr/local/Cellar/)



HomebrewCask

Homebrew cask



Cargo

Cargo/Rust (~/.cargo/bin/)



Pip

pip install –user



Pipx

pipx (~/.local/pipx/)



Uv

uv installed tools (~/.local/bin/ from uv)



Npm

npm global packages



Pyenv

pyenv (~/.pyenv/)



Rbenv

rbenv (~/.rbenv/)



Rvm

rvm (~/.rvm/)



Nvm

nvm (~/.nvm/)



Fnm

fnm (Fast Node Manager)



Volta

volta (~/.volta/)



Rustup

rustup (~/.rustup/)



Sdkman

sdkman (~/.sdkman/)



Gvm

gvm (~/.gvm/)



Mise

mise (~/.local/share/mise/)



Asdf

asdf (~/.asdf/)



Manual

Manual installation



Unknown

Unknown source

Implementations

Source

impl BinarySource

pub fn name(&self) -> &'static str

Get display name

pub fn is_version_manager(&self) -> bool

Is this a version manager?