pub struct GameDevCleaner { /* private fields */ }Expand description
Game Development cleaner
Implementations
Sourceimpl GameDevCleaner
impl GameDevCleaner
Sourcepub fn detect(&self) -> Result<Vec<CleanableItem>>
pub fn detect(&self) -> Result<Vec<CleanableItem>>
Detect all game development cleanable items
Sourcepub fn scan_unity_projects(
&self,
search_path: &PathBuf,
) -> Result<Vec<CleanableItem>>
pub fn scan_unity_projects( &self, search_path: &PathBuf, ) -> Result<Vec<CleanableItem>>
Scan for Unity project folders and their cleanable directories
Sourcepub fn scan_unreal_projects(
&self,
search_path: &PathBuf,
) -> Result<Vec<CleanableItem>>
pub fn scan_unreal_projects( &self, search_path: &PathBuf, ) -> Result<Vec<CleanableItem>>
Scan for Unreal project folders and their cleanable directories