pub enum DockerArtifactType {
DanglingImages,
UnusedImages,
UnusedVolumes,
BuildCache,
StoppedContainers,
}Expand description
Docker artifact types
Variants
DanglingImages
Dangling images (untagged)
UnusedImages
All unused images
UnusedVolumes
Unused volumes
BuildCache
Build cache
StoppedContainers
Stopped containers
Implementations
Sourceimpl DockerArtifactType
impl DockerArtifactType
Sourcepub fn list_command(&self) -> Vec<&'static str>
pub fn list_command(&self) -> Vec<&'static str>
Get the docker command to list this artifact type
Sourcepub fn clean_command(&self) -> Vec<&'static str>
pub fn clean_command(&self) -> Vec<&'static str>
Get the docker command to clean this artifact type